=================
 ``zope.minmax``
=================

.. image:: https://img.shields.io/pypi/v/zope.minmax.svg
        :target: https://pypi.python.org/pypi/zope.minmax/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/zope.minmax.svg
        :target: https://pypi.org/project/zope.minmax/
        :alt: Supported Python versions

.. image:: https://github.com/zopefoundation/zope.minmax/actions/workflows/tests.yml/badge.svg
        :target: https://github.com/zopefoundation/zope.minmax/actions/workflows/tests.yml

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.minmax/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.minmax?branch=master

.. image:: https://readthedocs.org/projects/zopeminmax/badge/?version=latest
        :target: https://zopeminmax.readthedocs.io/en/latest/
        :alt: Documentation Status

This package provides support for homogeneous values favoring maximum
or minimum (e.g., numbers) for ZODB conflict resolution.

See https://zopeminmax.readthedocs.io for a detailed description.
